#!/bin/bash
#
# source: http://downloads.sourceforge.net/project/hplip/hplip/3.10.9/hplip-3.10.9.tar.gz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="hpijs"
soft2="hplip"
softversion="3.10.9"
arch="i486"
cpu="i686"
packageversion="66.2"

buildir=$(pwd)
srcpkg="$buildir/hplip-$softversion.tar.gz"
src="$buildir/hplip-$softversion"
package="$soft-$softversion-$arch-$packageversion"
package2="$soft2-$softversion-$arch-$packageversion"
dest="$buildir/$package"
dest2="$buildir/$package2"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
# added fedora udev rules patch
cat $buildir/hplip-udev-rules.patch | patch -p1 --verbose
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --enable-hpijs-install \
  --enable-pp-build \
  --enable-hpcups-install \
  --enable-fax-build \
  --enable-udev-acl-rules \
  --enable-shadow-build \
  --enable-foomatic-drv-install \
  --disable-foomatic-ppd-install \
  --enable-cups-drv-install \
  --enable-cups-ppd-install \
  --enable-foomatic-rip-hplip-install \
  --enable-qt4 \
  --with-docdir=/usr/doc/$soft-$softversion \
  --with-hpppddir=/usr/share/cups/model/HP \
  --with-drvdir=/usr/share/cups/drv/hp
 
make -j4
make install DESTDIR=$dest rulesdir=/lib/udev/rules.d 

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# No thanks, we don't replace/add files which are part of other packages
rm -rf $dest/etc/sane.d

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler---------------------------------------------------------|
hpijs: hpijs - HP driver developed for printing, scanning, and faxing)
hpijs:
hpijs: hpijs, HP drivers developed for printing, scanning, and faxing with HP
hpijs: inkjet and laser based printers in Linux.
hpijs:
hpijs: The HPLIP project provides printing support for 1,971 HP printer models,
hpijs: including Deskjet, Officejet, Photosmart, PSC (Print Scan Copy),
hpijs: Business Inkjet, LaserJet, Edgeline MFP, and LaserJet MFP.
hpijs:
hpijs: For more information, see:  http://hplip.sf.net
hpijs:
EODESC

mkdir -p $dest2/install
mv $dest/etc $dest2
mkdir -p $dest2/usr/share/applications
mv $dest/usr/share/applications/hplip.desktop $dest2/usr/share/applications
mv $dest/usr/share/hplip $dest2/usr/share

# make hp-fax utils in the zenwalk menu
cat << "EOF" > $dest2/usr/share/applications/hp-fab.desktop
[Desktop Entry]
Categories=Application;Office;
Comment=A simple fax address book for HPLIP
Exec=/usr/bin/hp-fab
GenericName=Fax Address Book Application
Icon=/usr/share/hplip/data/images/32x32/fab.png
Name=HP Fax Address Book
Terminal=false
Type=Application
EOF

cat << "EOF" > $dest2/usr/share/applications/hp-sendfax.desktop
[Desktop Entry]
Categories=Application;Office;
Comment=Utility for sending faxes with HP's multi-function devices
Exec=/usr/bin/hp-sendfax
GenericName= Sending Faxes Application
Icon=/usr/share/hplip/data/images/32x32/fax_machine.png
Name=HP Sendfax
Terminal=false
Type=Application
EOF

#-----------------Make the slack-desc files

cat << EODESC > $dest2/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler----------------------------------------------------------|
hplip: hplip - HP Print, Scan and Fax support for Linux
hplip:
hplip: HPLIP (Hewlett-Packard Linux Imaging & Printing) is an HP-developed
hplip: solution for printing, scanning, and faxing with HP inkjet and laser 
hplip: based printers in Linux. The HPLIP project provides printing support for
hplip: 1,686 printer models, including Deskjet, Officejet, Photosmart, PSC
hplip: (Print Scan Copy), Business Inkjet, LaserJet, Edgeline MFP, and LaserJet
hplip: MFP. (Note: Not all models are currently supported. See Supported
hplip: Printers for more information.)
hplip:
hplip:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5

cd $dest2
makepkg -l y -c n $dest2.txz

cd $buildir
md5sum $package2.txz > $package2.md5